// jshint maxerr:1000
/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* ===============================================================================================================
   ===============================================================================================================
                                                     POWER TAB TOOL 
   ===============================================================================================================
   =============================================================================================================== 
*/
let Power_Error = {
    /**
     * An object holding all the error/condition checking functions. 
     * If the condition is triggered the function returns a list [1, 'error text'];
     * otherwise the function returns [0, ''] 
     */
    Rules: {
        check_antennaConfiguration: function(){
            if (mmWavePower.Input.num_rx == 1 & mmWavePower.Input.num_tx == 2){
                ['ti_widget_container_output_active_usage',
                'ti_widget_container_output_avg_power'].forEach(widget => {
                    Util.Html.highlightPropWithPrecedence(templateObj.$[widget], 1, 'conditional');
                });
                return [1, 'Invalid antenna configuration, 2Tx-1Rx power calculations not currently supported'];
            }
            return [0, ''];
        },
        check_numOfChirpsInBurst: function() {
            if (mmWavePower.Input.numchirps < 1 || mmWaveAdvanced.Input.numchirps > 65535) {
                Util.Html.highlightPropWithPrecedence(templateObj.$.ti_widget_container_power_output_active_time,1,'conditional');
                return [1, 'numOfChirpsInBurst must be between 1 and 65535'];
            }
            return [0, ''];
        },
        check_numOfBurstsInFrame: function() {
            if (mmWavePower.Input.numbursts < 1 || mmWaveAdvanced.Input.numbursts > 4096) {
                Util.Html.highlightPropWithPrecedence(templateObj.$.ti_widget_container_power_output_active_time,1,'conditional');
                return [1, 'numOfBurstsInFrame must be between 1 and 4096'];
            }
            return [0, ''];
        }
    },
};
/**
 * A mapping to tie the front end widgets to their error-checking function.
 */
let Power_ErrorMaps = {
    /**
     * A mapping to tie the front end widgets to their error-checking function.
     */
    Err: [
        [['ti_widget_container_power_num_rx',
          'ti_widget_container_power_num_tx'],      Power_Error.Rules.check_antennaConfiguration],
        [['ti_widget_container_power_numchirps'],   Power_Error.Rules.check_numOfChirpsInBurst],
        [['ti_widget_container_power_numbbursts'],  Power_Error.Rules.check_numOfBurstsInFrame],
        
    ],
    Warn: [],
    /**
     * Cells that are ever highlighted as "related" (conditional)
     */
    Related: [
        'ti_widget_container_output_active_usage',
        'ti_widget_container_output_avg_power',
        'ti_widget_container_power_output_active_time',
    ],
};
